@@ -125,7 +125,7 @@ class TestServer:
             coros = []
             for conn in self.connections:
                 if hasattr(conn, "websocket") and conn.websocket:
-                    coros.append(conn.websocket.close_connection(after_handshake=False))
+                    coros.append(conn.websocket.close_connection())
                 else:
                     conn.close()
             await asyncio.gather(*coros, loop=self.loop)
